package
Version:
v0.0.0-...-d2e785b
Opens a new window with list of versions in this module.
Published: Jan 17, 2018
License: MPL-2.0
Opens a new window with license information.
Imports: 17
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Build struct {
ID string `json:"id"`
Name string `json:"name"`
Status string `json:"status"`
CreatedAt string `json:"created_at"`
}
type Env struct {
ID int `json:"id"`
Name string `json:"name"`
Status string `json:"status"`
}
type UniqueCollection []string
Source Files
¶
Click to show internal directories.
Click to hide internal directories.